import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from 'react';
import PropTypes from 'prop-types';
import MUIButton from '@material-ui/core/Button';
import { withStyles } from '@material-ui/styles';
import cx from 'clsx';
import SvgIcon from '../SvgIcon/SvgIcon';

var styleClasses = function styleClasses(theme) {
  var _rightIcon, _label;

  return {
    root: _defineProperty({
      border: 0,
      height: '48px',
      boxShadow: 'none',
      color: theme.palette.common.white,
      padding: '0 16px',
      textTransform: 'none',
      width: '100%',
      textAlign: 'center'
    }, theme.breakpoints.up('md'), {
      width: '314px'
    }),
    label: (_label = {
      fontSize: '18px'
    }, _defineProperty(_label, theme.breakpoints.up('md'), {
      fontSize: '20px'
    }), _defineProperty(_label, '& .leftIcon', _defineProperty({
      paddingTop: 8,
      paddingRight: 4,
      '& svg': {
        width: 24,
        height: 24
      }
    }, theme.breakpoints.between('md', 'lg'), {
      left: 24
    })), _defineProperty(_label, '& .rightIcon', (_rightIcon = {
      paddingTop: 8,
      position: 'absolute',
      right: 16,
      '& svg': {
        width: 30,
        height: 30
      }
    }, _defineProperty(_rightIcon, theme.breakpoints.between('md', 'lg'), {
      right: 12
    }), _defineProperty(_rightIcon, theme.breakpoints.between('xs', 'sm'), {
      right: 0
    }), _rightIcon)), _label),
    containedPrimary: {
      background: theme.palette.primary.main,
      '&:active,&:hover': {
        background: theme.palette.primary.dark
      },
      '&:disabled': {
        background: theme.palette.disabled.main,
        color: theme.palette.common.white
      }
    },
    containedSecondary: {
      color: theme.palette.primary.main,
      border: '1px solid',
      borderColor: theme.palette.primary.main,
      background: theme.palette.colorVariables.TRANSPARENT,
      '&:active,&:hover': {
        background: theme.palette.colorVariables.SECONDARY_HOVER
      },
      '&:disabled': {
        background: theme.palette.colorVariables.TRANSPARENT,
        borderColor: theme.palette.disabled.main
      }
    }
  };
};

function Button(_ref) {
  var children = _ref.children,
      className = _ref.className,
      classes = _ref.classes,
      disabled = _ref.disabled,
      id = _ref.id,
      color = _ref.color,
      href = _ref.href,
      forwardedRef = _ref.forwardedRef,
      onClick = _ref.onClick,
      leftIcon = _ref.leftIcon,
      rightIcon = _ref.rightIcon,
      loading = _ref.loading;
  return React.createElement(MUIButton, {
    className: cx('Button', classes.root, className),
    classes: classes,
    disabled: disabled,
    disableRipple: true,
    "data-quid": id,
    color: color,
    variant: "contained",
    href: href,
    ref: forwardedRef,
    onClick: onClick
  }, leftIcon && React.createElement(SvgIcon, {
    className: cx("leftIcon"),
    svgIcon: leftIcon
  }), children, loading && rightIcon && React.createElement(SvgIcon, {
    className: cx("rightIcon"),
    svgIcon: rightIcon
  }));
}

Button.defaultProps = {
  color: 'primary',
  href: null,
  forwardedRef: React.createRef()
};
export default withStyles(styleClasses, {
  index: 0,
  withTheme: true
})(Button);